@@ -77,6 +77,14 @@ class BaseResource(object):
         data = json.dumps(data, cls=UnitEncoder) if data is not None else None
         return requests.post(f"{self.api_url}/{resource}", data=data, headers=self.__merge_headers(headers))
 
+    @backoff.on_predicate(backoff.expo,
+                          backoff_handler,
+                          max_tries=get_max_retries,
+                          jitter=backoff.random_jitter)
+    def post_full_path(self, path: str, data: Optional[Dict] = None, headers: Optional[Dict[str, str]] = None):
+        data = json.dumps(data, cls=UnitEncoder) if data is not None else None
+        return requests.post(path, data=data, headers=self.__merge_headers(headers))
+
     @backoff.on_predicate(backoff.expo,
                           backoff_handler,
                           max_tries=get_max_retries,
