@@ -362,18 +362,19 @@ class ReturnedCheckDepositTransactionDTO(BaseTransactionDTO):
                                                   attributes["amount"], attributes["balance"], attributes["summary"],
                                                   attributes["reason"], attributes.get("tags"), relationships)
 
+
 class PaymentAdvanceTransactionDTO(BaseTransactionDTO):
     def __init__(self, id: str, created_at: datetime, direction: str, amount: int, balance: int, summary: str,
-                 reason: str, tags: Optional[Dict[str, str]], relationships: Optional[Dict[str, Relationship]]):
+                 tags: Optional[Dict[str, str]], relationships: Optional[Dict[str, Relationship]]):
         BaseTransactionDTO.__init__(self, id, created_at, direction, amount, balance, summary, tags, relationships)
         self.type = 'paymentAdvanceTransaction'
 
     @staticmethod
     def from_json_api(_id, _type, attributes, relationships):
         return PaymentAdvanceTransactionDTO(_id, date_utils.to_datetime(attributes["createdAt"]),
-                                                  attributes["direction"],
-                                                  attributes["amount"], attributes["balance"], attributes["summary"],
-                                                  attributes.get("tags"), relationships)
+                                            attributes["direction"], attributes["amount"], attributes["balance"],
+                                            attributes["summary"], attributes.get("tags"), relationships)
+
 
 class RepaidPaymentAdvanceTransactionDTO(BaseTransactionDTO):
     def __init__(self, id: str, created_at: datetime, direction: str, amount: int, balance: int, summary: str,
@@ -507,4 +508,5 @@ class ListTransactionParams(UnitParams):
             parameters["sort"] = self.sort
         if self.include:
             parameters["include"] = self.include
-        return parameters
\ No newline at end of file
+        return parameters
+
